@@ -7,7 +7,7 @@ from pycoin.encoding.hexbytes import b2h_rev
 
 class BlockExplorerProvider(object):
     def __init__(self, netcode):
-        url_stub = {"BTC": "blockexplorer.com", "XTN": "testnet.blockexplorer.com"}.get(netcode)
+        url_stub = {"BTC": "blockexplorer.com", "XTN": "testnet.blockexplorer.com", "BCH": "bitcoincash.blockexplorer.com"}.get(netcode)
         if url_stub is None:
             raise ValueError("unsupported netcode %s" % netcode)
         self.url = "https://%s/api" % url_stub
